==> nextcloud-php72-19.0.3.txz: usr/local/www/nextcloud/apps-pkg/files/l10n/es.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
    "Storage invalid" : "Almacenamiento no válido",
    "Unknown error" : "Error desconocido",
    "File could not be found" : "El archivo no se ha encontrado",
    "Move or copy" : "Mover o copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Home" : "Inicio",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
    "This will stop your current uploads." : "Esto detendrá las subidas en curso.",
    "Upload cancelled." : "Subida cancelada.",
    "Processing files …" : "Procesando archivos …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
    "Not enough free space" : "No hay espacio libre suficiente",
    "An unknown error has occurred" : "Ha ocurrido un error desconocido",
    "Uploading …" : "Subiendo …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Subir este archivo no es compatible",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Operation is blocked by access control" : "Esta operación está bloqueada por el control de accesos",
    "Error when assembling chunks, status code {status}" : "Error al reunir los trozos, código de estado {status}",
    "Actions" : "Acciones",
    "Rename" : "Renombrar",
    "Copy" : "Copiar",
    "Choose target folder" : "Elegir carpeta de destino",
    "Open" : "Abrir",
    "Delete file" : "Eliminar archivo",
    "Delete folder" : "Eliminar carpeta",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Leave this share" : "Dejar de compartir",
    "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No se ha podido determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
    "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", ya existe",
    "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "No se ha podido copiar \"{file}\", ya existe el destino",
    "Could not copy \"{file}\"" : "No se ha podido copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Se ha copiado {origin} dentro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Se han copiado {origin} y {nbfiles} otros archivos dentro de {destination}",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
    "Could not rename \"{fileName}\"" : "No se pudo renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No se pudo crear archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No se ha podido crear la carpeta \"{dir}\" porque ya existe",
    "Could not fetch file details \"{file}\"" : "No se pudieron obtener los detalles de \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados de búsqueda en otras carpetas para  {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Escriba más de dos caracteres para buscar en otras carpetas",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos"],
    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "Select file range" : "Seleccionar el rango de archivos",
    "{used} of {quota} used" : "{used} usados de {quota}",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "\"/\" no se permite en un nombre de archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El espacio de {owner} está lleno, ¡no se subirán ni se sincronizarán más archivos!",
    "This group folder is full, files can not be updated or synced anymore!" : "Esta carpeta de grupo está llena, los archivos no pueden ser actualizados o sincronizados más.",
    "This external storage is full, files can not be updated or synced anymore!" : "Este almacenamiento externo está lleno, los archivos no pueden ser subidos o sincronizados más.",
    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno, ¡no se subirán ni se sincronizarán más archivos!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
    "This group folder is almost full ({usedSpacePercent}%)." : "Esta carpeta de grupo está casi llena ({usedSpacePercent}%).",
    "This external storage is almost full ({usedSpacePercent}%)." : "Este almacenamiento externo está casi lleno ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
    "View in folder" : "Ver en carpeta",
    "Copied!" : "¡Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Agregado a favoritos",
    "Favorite" : "Favorito",
    "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un solo archivo o carpeta cada vez",
    "New folder" : "Nueva carpeta",
    "Upload file" : "Subir archivo",
    "Recent" : "Reciente",
    "Not favorited" : "Quitado como favorito",
    "Remove from favorites" : "Quitar de favoritos",
    "Add to favorites" : "Añadir a favoritos",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "Added to favorites" : "Agregado a favoritos",
    "Removed from favorites" : "Quitado de favoritos",
    "You added {file} to your favorites" : "Has agregado {file} a tus favoritos",
    "You removed {file} from your favorites" : "Has quitado {file} de tus favoritos",
    "File changes" : "Cambios del archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuario remoto\"",
    "You created {file}" : "Ha creado {file}",
    "You created an encrypted file in {file}" : "Has creado un archivo cifrado en {file}",
    "{user} created {file}" : "{user} ha creado {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creado un archivo cifrado en {file}",
    "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
    "You changed {file}" : "Has cambiado {file}",
    "You changed an encrypted file in {file}" : "Has modificado un archivo cifrado en {file}",
    "{user} changed {file}" : "{user} ha cambiado {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha modificado un archivo cifrado en {file}",
    "You deleted {file}" : "Has borrado {file}",
    "You deleted an encrypted file in {file}" : "Has borrado un archivo cifrado en {file}",
    "{user} deleted {file}" : "{user} eliminó {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha borrado un archivo cifrado en {file}",
    "You restored {file}" : "Has restaurado {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Has movido {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo fue agregado o borrado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
    "All files" : "Todos los archivos",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "Accept" : "Aceptar",
    "Reject" : "Rechazar",
    "Incoming ownership transfer from {user}" : "Ha llegado una transferencia de propiedad de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
    "Ownership transfer failed" : "Fallo al transferir la propiedad",
    "Your ownership transfer of {path} to {user} failed." : "Ha fallado tu transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
    "Ownership transfer done" : "Transferencia de propiedad realizada",
    "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
    "in %s" : "en %s",
    "File Management" : "Gestión de archivos",
    "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
    "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Change" : "Cambiar",
    "New owner" : "Nuevo propietario",
    "Search users" : "Buscar usuarios",
    "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
    "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
    "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
    "Cannot transfer ownership of a file or folder you don't own" : "No se puede transferir la propiedad de un archivo o carpeta que no te pertenece",
    "Tags" : "Etiquetas",
    "Error while loading the file data" : "Error al cargar los datos del archivo",
    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
    "%s used" : "usado %s",
    "%s%% of %s used" : "%s%% de %s usado",
    "%1$s of %2$s used" : "%1$s de %2$s usados",
    "Settings" : "Ajustes",
    "Show hidden files" : "Mostrar archivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
    "Toggle grid view" : "Alternar vista de cuadrícula",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
    "Deleted files" : "Archivos eliminados",
    "Shares" : "Archivos compartidos",
    "Shared with others" : "Compartido con otros",
    "Shared with you" : "Compartido conmigo",
    "Shared by link" : "Compartido por enlace",
    "Deleted shares" : "Recursos compartidos eliminados",
    "Pending shares" : "Recursos compartidos pendientes",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo.txt",
    "Unshare" : "Dejar de compartir",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El espacio de {owner} está casi lleno en un ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tu espacio está casi lleno, ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>",
    "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaciones sobre la creación y cambios en tus <strong>archivos favoritos</strong> <em>(solo transmisión)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Usa esta dirección para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">acceder a tus archivos vía WebDAV</a>",
    "Cannot transfter ownership of a file or folder you don't own" : "No se puede transferir la propiedad de un archivo o carpeta que no te pertenece",
    "This group folder is almost full ({usedSpacePercent}%)" : "Esta carpeta de grupo está casi llena ({usedSpacePercent}%)",
    "This external storage is almost full ({usedSpacePercent}%)" : "Este almacenamiento externo está casi lleno ({usedSpacePercent}%)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-php74-20.0.7.txz: usr/local/www/nextcloud/apps-pkg/files/l10n/es.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
    "Storage invalid" : "Almacenamiento no válido",
    "Unknown error" : "Error desconocido",
    "File could not be found" : "El archivo no se ha encontrado",
    "Move or copy" : "Mover o copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Home" : "Inicio",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
    "This will stop your current uploads." : "Esto detendrá las subidas en curso.",
    "Upload cancelled." : "Subida cancelada.",
    "Processing files …" : "Procesando archivos …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
    "Not enough free space" : "No hay espacio libre suficiente",
    "An unknown error has occurred" : "Ha ocurrido un error desconocido",
    "Uploading …" : "Subiendo …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Subir este archivo no es compatible",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Operation is blocked by access control" : "Esta operación está bloqueada por el control de accesos",
    "Error when assembling chunks, status code {status}" : "Error al reunir los trozos, código de estado {status}",
    "Actions" : "Acciones",
    "Rename" : "Renombrar",
    "Copy" : "Copiar",
    "Choose target folder" : "Elegir carpeta de destino",
    "Open" : "Abrir",
    "Delete file" : "Eliminar archivo",
    "Delete folder" : "Eliminar carpeta",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Leave this share" : "Dejar de compartir",
    "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No se ha podido determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
    "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", ya existe",
    "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "No se ha podido copiar \"{file}\", ya existe el destino",
    "Could not copy \"{file}\"" : "No se ha podido copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Se ha copiado {origin} dentro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Se han copiado {origin} y {nbfiles} otros archivos dentro de {destination}",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
    "Could not rename \"{fileName}\"" : "No se pudo renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No se pudo crear archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No se ha podido crear la carpeta \"{dir}\" porque ya existe",
    "Could not fetch file details \"{file}\"" : "No se pudieron obtener los detalles de \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados de búsqueda en otras carpetas para  {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Escriba más de dos caracteres para buscar en otras carpetas",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos"],
    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "Select file range" : "Seleccionar el rango de archivos",
    "{used} of {quota} used" : "{used} usados de {quota}",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "\"/\" no se permite en un nombre de archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El espacio de {owner} está lleno, ¡no se subirán ni se sincronizarán más archivos!",
    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "¡La carpeta de grupo  \"{mountPoint}\" está llena, los archivos ya no pueden ser actualizados o sincronizados!.",
    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "¡El almacenamiento externo  \"{mountPoint}\" está lleno, los archivos ya no pueden ser actualizados o sincronizados!.",
    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno, ¡no se subirán ni se sincronizarán más archivos!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
    "View in folder" : "Ver en carpeta",
    "Copied!" : "¡Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Agregado a favoritos",
    "Favorite" : "Favorito",
    "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un solo archivo o carpeta cada vez",
    "New folder" : "Nueva carpeta",
    "Upload file" : "Subir archivo",
    "Recent" : "Reciente",
    "Not favorited" : "Quitado como favorito",
    "Remove from favorites" : "Quitar de favoritos",
    "Add to favorites" : "Añadir a favoritos",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "Added to favorites" : "Agregado a favoritos",
    "Removed from favorites" : "Quitado de favoritos",
    "You added {file} to your favorites" : "Has agregado {file} a tus favoritos",
    "You removed {file} from your favorites" : "Has quitado {file} de tus favoritos",
    "File changes" : "Cambios del archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuario remoto\"",
    "You created {file}" : "Ha creado {file}",
    "You created an encrypted file in {file}" : "Has creado un archivo cifrado en {file}",
    "{user} created {file}" : "{user} ha creado {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creado un archivo cifrado en {file}",
    "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
    "You changed {file}" : "Has cambiado {file}",
    "You changed an encrypted file in {file}" : "Has modificado un archivo cifrado en {file}",
    "{user} changed {file}" : "{user} ha cambiado {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha modificado un archivo cifrado en {file}",
    "You deleted {file}" : "Has borrado {file}",
    "You deleted an encrypted file in {file}" : "Has borrado un archivo cifrado en {file}",
    "{user} deleted {file}" : "{user} eliminó {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha borrado un archivo cifrado en {file}",
    "You restored {file}" : "Has restaurado {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Has movido {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo fue agregado o borrado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
    "All files" : "Todos los archivos",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "Accept" : "Aceptar",
    "Reject" : "Rechazar",
    "Incoming ownership transfer from {user}" : "Ha llegado una transferencia de propiedad de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
    "Ownership transfer failed" : "Fallo al transferir la propiedad",
    "Your ownership transfer of {path} to {user} failed." : "Ha fallado tu transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
    "Ownership transfer done" : "Transferencia de propiedad realizada",
    "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
    "in %s" : "en %s",
    "File Management" : "Gestión de archivos",
    "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
    "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Change" : "Cambiar",
    "New owner" : "Nuevo propietario",
    "Search users" : "Buscar usuarios",
    "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
    "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
    "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
    "Cannot transfer ownership of a file or folder you don't own" : "No se puede transferir la propiedad de un archivo o carpeta que no te pertenece",
    "Tags" : "Etiquetas",
    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
    "Error while loading the file data" : "Error al cargar los datos del archivo",
    "Pick a template for {name}" : "Elija una plantilla para {name}",
    "Cancel" : "Cancelar",
    "Create" : "Crear",
    "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
    "Creating file" : "Creando el archivo",
    "Blank" : "Vacío",
    "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
    "Set up templates folder" : "Configura una carpeta para plantillas",
    "Templates" : "Plantillas",
    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
    "%s used" : "usado %s",
    "%s%% of %s used" : "%s%% de %s usado",
    "%1$s of %2$s used" : "%1$s de %2$s usados",
    "Settings" : "Ajustes",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Crop image previews" : "Recortar la previsualización de las imágenes",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
    "Toggle grid view" : "Alternar vista de cuadrícula",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
    "Deleted files" : "Archivos eliminados",
    "Shares" : "Archivos compartidos",
    "Shared with others" : "Compartido con otros",
    "Shared with you" : "Compartido conmigo",
    "Shared by link" : "Compartido por enlace",
    "Deleted shares" : "Recursos compartidos eliminados",
    "Pending shares" : "Recursos compartidos pendientes",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo.txt",
    "Unshare" : "Dejar de compartir",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El espacio de {owner} está casi lleno en un ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%)",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Tu espacio está casi lleno, ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>",
    "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaciones sobre la creación y cambios en tus <strong>archivos favoritos</strong> <em>(solo transmisión)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>"
},
"nplurals=2; plural=(n != 1);");
